@@ -1,3 +1,4 @@
+use 5.008;
 use strict;
 use warnings;
 
@@ -6,7 +7,7 @@ BEGIN {
   $Task::BeLike::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Modules SCHWIGON uses
-$Task::BeLike::SCHWIGON::VERSION = '0.004';
+$Task::BeLike::SCHWIGON::VERSION = '0.005';
 
 1;
 
@@ -22,7 +23,7 @@ Task::BeLike::SCHWIGON - Modules SCHWIGON uses
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 TASK CONTENTS
 
@@ -44,10 +45,14 @@ version 0.004
 
 =head3 L<CPAN::Uploader>
 
+=head3 L<File::Rsync::Mirror::Recent>
+
 =head2 Optional Dependencies Of Other Modules
 
 =head3 L<CPAN::Reporter>
 
+=head3 L<Git::Repository>
+
 =head3 L<PadWalker>
 
 =head3 L<Task::SDK::Moose>
@@ -230,6 +235,8 @@ version 0.004
 
 =head3 L<Parse::RecDescent>
 
+=head3 L<PAR::Packer>
+
 =head3 L<Regexp::Common>
 
 =head3 L<SQL::Translator>
@@ -260,6 +267,8 @@ version 0.004
 
 =head3 L<URI::Escape>
 
+=head3 L<XML::Mini::Document>
+
 =head3 L<YAML>
 
 =head3 L<YAML::Syck>
